import logging
from dlist_top import Client
from .config import TOKEN

# class Test(Base):
#     a: Unix

# x = Test(a = 1619220922087)
# print(x.a)


logging.basicConfig(level=logging.INFO)

dlist = Client(token=TOKEN)
dlist.connect()

@dlist.on('rate')
def on_rate(data):
    print(data)
    
@dlist.on('vote')
def on_vote(data):
    print(data)


from types import SimpleNamespace
from typing import Any

class Base(SimpleNamespace):
    def __init__(self, **kwargs: Any) -> None:
        super().__init__(**kwargs)

        for k, Type in self.__annotations__.items():
            if Type is Any or Type is None: continue

            old = self.__dict__[k] \
                if k in self.__dict__ \
                else None

            try:
                try:
                    self.__dict__[k] = Type.parse(old)
                except AttributeError:
                    self.__dict__[k] = Type(old)

            except Exception as err:
                raise type(err)(f'cannot {k} to type {Type}: {err}') from None


from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='dlist_top',
    version='0.1.0',
    description='DList.top client for Python',
    long_description=readme,
    long_description_content_type="text/markdown",
    author='DList.top',
    # author_email='',
    url='https://github.com/dlist-top/client-py',
    license=license,
    packages=find_packages(where='dlist_top', exclude=('test')),
    package_dir={"": "dlist_top"},
    python_requires=">=3.8",
)



from dlist_top.types.timestamp import Timestamp
from types import SimpleNamespace
from typing import Any
from .entity import EntityType
from .timestamp import Timestamp
from .base import Base

class VoteData(Base):
    authorID: str
    entityType: EntityType
    entityID: str
    date: Timestamp
    totalVotes: int
    userVotes: int

class RateData(Base):
    authorID: str
    entityType: EntityType
    entityID: str
    rating: int
    details: str
    date: Timestamp

event_classes = {
    'VOTE': VoteData,
    'RATE': RateData
}


from dlist_top.types.base import Base
from types import SimpleNamespace
from typing import Any
from enum import Enum
from .base import Base

class GatewayOP(Enum):
    HELLO = 1
    IDENTIFY = 2
    READY = 3
    DISCONNECT = 4
    EVENT = 5

class GatewayPayload(Base):
    op: GatewayOP
    data: Any
    event: str